package org.deken.game.sprites;


import org.deken.game.animation.Animation;

/**
 * <p>Title: Decor</p>
 *
 * <p>Description: An unmoving Sprite</p>
 *
 * <p>Copyright: Copyright (c) 2002</p>
 *
 * <p>@author Gary Deken</p>
 * @version 1.0
 */
public class Decor extends Sprite {
   private Animation animation;

   /**
    * Decor
    * This constructor is used by the DocumentManager. It is not
    * recommended to use this outside of that class.
    *
    * @param size SpriteSize
    */
   public Decor(SpriteSize size) {
      super(size);
   }

   /**
    * Decor
    *
    * @param animation Animation
    * @param size SpriteSize
    */
   public Decor(Animation animation, SpriteSize size) {
      super(size);
      this.animation = animation;
   }

   /**
    * getAnimation
    *
    * <p>Retrieve the animation strip for this sprite.</p>
    *
    * @return Animation
    */
   public Animation getAnimation() {
      return animation;
   }

   /**
    * setAnimation
    *
    * <p>This sets the animation strip for the this sprite.</p>
    *
    * @param animation Animation
    */
   public void setAnimation(Animation animation) {
      this.animation = animation;
   }

   /**
    * update
    *
    * @param elapseTime long
    */
   public void update(long elapseTime) {
      if (animation != null) {
         animation.update(elapseTime);
      }
   }

   /**
    * Draw
    * @param xOffset
    * @param yOffset
    */
   @Override
   public void draw(int xOffset, int yOffset) {
      getAnimation().draw((int) location.getX() + xOffset,
         (int) location.getY() + yOffset);
   }

   /**
    * clone
    *
    * @return Actor
    */
   public Decor cloneBase(Decor newDecor) {
      newDecor.animation = (Animation) this.animation.clone();
      newDecor.size = (SpriteSize) this.getSize().clone();

      return newDecor;
   }

   /**
    * clone
    *
    * @return Object
    */
   public Object clone() {
      Decor decor = new Decor((Animation) this.animation.clone(), (SpriteSize) this.getSize().clone());
      return decor;
   }
}
