package org.deken.game.sprites;

import org.deken.game.map.GameLocation;
import java.awt.geom.Rectangle2D;

import org.deken.game.Updateable;
import org.deken.game.util.GameLog;

/**
 * <p>Title: Sprite</p>
 *
 * <p>Description: Base Sprite for all game items</p>
 *
 * <p>Copyright: Copyright (c) 2005</p>
 *
 * <p>@author Gary Deken</p>
 * @version 1.0
 */
public abstract class Sprite implements Updateable, Cloneable {
   protected SpriteSize size;
   protected GameLocation location = new GameLocation();
   private Rectangle2D.Double rectangle = new Rectangle2D.Double();

   /**
    * Sprite
    */
   public Sprite() {
      // set all to default
      size = new SpriteSize();
      location = new GameLocation();
   }

   /**
    * Sprite
    *
    * @param size SpriteSize
    */
   public Sprite(SpriteSize size) {
      this.size = size;
   }

   /**
    * update
    *
    * @param elapseTime long
    */
   public abstract void update(long elapseTime);

   /**
    * clone
    *
    * @return Object
    */
   @Override
   public abstract Object clone();

   /**
    * Draws the sprite with the current offset.
    * @param xOffset
    * @param yOffset
    */
   public abstract void draw(int xOffset, int yOffset);

   /**
    * getBounds
    *
    * @return Rectangle2D
    */
   public Rectangle2D getBounds() {
      rectangle.setRect(getXLocation(), getYLocation(), size.getWidth(), size.getHeight());
      return rectangle;
   }

   /**
    * getSize
    *
    * @return SpriteSize
    */
   public SpriteSize getSize() {
      return size;
   }

   /**
    * getLocation
    *
    * @return GameLocation
    */
   public GameLocation getLocation() {
      return location;
   }

   /**
    * setSize
    *
    * @param spriteSize SpriteSize
    */
   public void setSize(SpriteSize spriteSize) {
      size = spriteSize;
   }

   /**
    * setLocation
    *
    * @param location GameLocation
    */
   public void setLocation(GameLocation location) {
      this.location = location;
   }

   /**
    * getHeight
    *
    * @return int
    */
   public int getHeight() {
      return size.getHeight();
   }

   /**
    * getWidth
    *
    * @return int
    */
   public int getWidth() {
      return size.getWidth();
   }

   /**
    * getXLocation
    *
    * @return double
    */
   public double getXLocation() {
      return location.getX();
   }

   /**
    * getYLocation
    *
    * @return double
    */
   public double getYLocation() {
      return location.getY();
   }
}
