package org.deken.game.sprites;

import java.lang.reflect.Constructor;
import org.deken.exception.FactoryException;
import java.lang.reflect.InvocationTargetException;

/**
 * <p>Title: SpriteFactory</p>
 *
 * <p>Description: </p>
 *
 * <p>Copyright: (c) 2009</p>
 *
 * <p>@author Gary Deken</p>
 * @version 1.0
 */
public class SpriteFactory {

  public SpriteFactory() {
  }

  public Sprite createGenericSprite(Class spriteClass, SpriteSize size) {
    Sprite sprite = null;

    Class clazz[] = new Class[] {SpriteSize.class};
    Object[] args = new Object[] {size};

    try {
      // get the constructor
      Constructor constr = spriteClass.getConstructor(clazz);
      // instantiate the class.
      sprite = (Sprite) constr.newInstance(args);
    }
    catch (SecurityException ex) {
      throw new FactoryException("Not enough Security permission to get constructor " + spriteClass.getName(), ex);
    }
    catch (NoSuchMethodException ex) {
      throw new FactoryException("The Sprite class does not have the correct constructor./r/n", ex);
    }
    catch (InvocationTargetException ex) {
      throw new FactoryException("Unable to create a new Instance of " + spriteClass.getName(), ex);
    }
    catch (IllegalArgumentException ex) {
      throw new FactoryException("The Sprite class does not have the correct constructor./r/n", ex);
    }
    catch (IllegalAccessException ex) {
      throw new FactoryException("The Constructor is not accessable in " + spriteClass.getName(), ex);
    }
    catch (InstantiationException ex) {
      throw new FactoryException("Unable to create a new Instance of " + spriteClass.getName(), ex);
    }

    return sprite;
  }

  /**
   * createDecor
   *
   * @param size SpriteSize
   * @return Decor
   */
  public Decor createDecor(SpriteSize size) {
    return (Decor) createGenericSprite(Decor.class, size);
  }

  /**
   * createActor
   *
   * @param size SpriteSize
   * @return BaseActor
   */
  public BaseActor createActor(SpriteSize size) {
   return (BaseActor) createGenericSprite(BaseActor.class, size);
  }

}
